diff --git a/entity/AnyContact_entity/entityfields/contacttype/valueProcess.js b/entity/AnyContact_entity/entityfields/contacttype/valueProcess.js
index 32bb8ca1976dad71cedfc90616c378fce1d9ccde..1974bb4d5a7c88145de2d44d53a22c00ece7aab3 100644
--- a/entity/AnyContact_entity/entityfields/contacttype/valueProcess.js
+++ b/entity/AnyContact_entity/entityfields/contacttype/valueProcess.js
@@ -2,4 +2,4 @@ import("system.result");
 import("system.vars");
 import("Contact_lib")
 
-result.object(ContactUtils.getRelationType(vars.get("$field.CONTACTID"), vars.get("$field.PERSON_ID"), vars.get("$field.ORGANISATION_ID")));
\ No newline at end of file
+result.object(ContactUtils.getContactType(vars.get("$field.CONTACTID"), vars.get("$field.PERSON_ID"), vars.get("$field.ORGANISATION_ID")));
\ No newline at end of file
diff --git a/entity/AnyContact_entity/recordcontainers/db/fromClauseProcess.js b/entity/AnyContact_entity/recordcontainers/db/fromClauseProcess.js
index c2008fc0d19dfe96ca7074d6f2ceddf2c5941f78..7dc4c1aa3f7ef16b0515795e0db3bfd3aabff75a 100644
--- a/entity/AnyContact_entity/recordcontainers/db/fromClauseProcess.js
+++ b/entity/AnyContact_entity/recordcontainers/db/fromClauseProcess.js
@@ -1,4 +1,4 @@
 import("system.result");
 import("Contact_lib")
 
-result.string(ContactUtils.getFullRelationString());
\ No newline at end of file
+result.string(ContactUtils.getFullContactString());
\ No newline at end of file
diff --git a/entity/Contract_entity/entityfields/contact_id/linkedContextProcess.js b/entity/Contract_entity/entityfields/contact_id/linkedContextProcess.js
index e678b842c5b6cf510473693a355fa7833dcf28e8..2e504d63e3b5a3f71b54b072798b3ad09c50984b 100644
--- a/entity/Contract_entity/entityfields/contact_id/linkedContextProcess.js
+++ b/entity/Contract_entity/entityfields/contact_id/linkedContextProcess.js
@@ -2,4 +2,4 @@ import("system.vars");
 import("system.result");
 import("Contact_lib");
 
-result.string(ContactUtils.getContextByRelationId(vars.getString("$field.CONTACT_ID")));
\ No newline at end of file
+result.string(ContactUtils.getContextByContactId(vars.getString("$field.CONTACT_ID")));
\ No newline at end of file
diff --git a/entity/Offer_entity/entityfields/activities/children/presetlinks_param/valueProcess.js b/entity/Offer_entity/entityfields/activities/children/presetlinks_param/valueProcess.js
index db35a547ac2cbf60774b6ddb9be4781b81196a68..e4c6c134df6be187331e47d8c2c4d5a9871b7c2b 100644
--- a/entity/Offer_entity/entityfields/activities/children/presetlinks_param/valueProcess.js
+++ b/entity/Offer_entity/entityfields/activities/children/presetlinks_param/valueProcess.js
@@ -7,7 +7,7 @@ var links = [];
 
 if (contactId)
 {
-    links.push([ContactUtils.getContextByRelationId(contactId), contactId]);
+    links.push([ContactUtils.getContextByContactId(contactId), contactId]);
 }
 
 if (vars.get("$field.SALESPROJECT_ID"))
diff --git a/entity/Offer_entity/entityfields/contact_id/linkedContextProcess.js b/entity/Offer_entity/entityfields/contact_id/linkedContextProcess.js
index e678b842c5b6cf510473693a355fa7833dcf28e8..2e504d63e3b5a3f71b54b072798b3ad09c50984b 100644
--- a/entity/Offer_entity/entityfields/contact_id/linkedContextProcess.js
+++ b/entity/Offer_entity/entityfields/contact_id/linkedContextProcess.js
@@ -2,4 +2,4 @@ import("system.vars");
 import("system.result");
 import("Contact_lib");
 
-result.string(ContactUtils.getContextByRelationId(vars.getString("$field.CONTACT_ID")));
\ No newline at end of file
+result.string(ContactUtils.getContextByContactId(vars.getString("$field.CONTACT_ID")));
\ No newline at end of file
diff --git a/entity/Offer_entity/entityfields/newactivity/onActionProcess.js b/entity/Offer_entity/entityfields/newactivity/onActionProcess.js
index d0e6ebcf2bdd9a61c92ebde5728203de9d3f0c99..4be677edd52ad21e51db57a867790397f1fe35bc 100644
--- a/entity/Offer_entity/entityfields/newactivity/onActionProcess.js
+++ b/entity/Offer_entity/entityfields/newactivity/onActionProcess.js
@@ -7,7 +7,7 @@ var links = [];
 
 if (contactId)
 {
-    links.push([ContactUtils.getContextByRelationId(contactId), contactId]);
+    links.push([ContactUtils.getContextByContactId(contactId), contactId]);
 }
 
 if (vars.get("$field.SALESPROJECT_ID"))
diff --git a/entity/Offer_entity/entityfields/newtask/onActionProcess.js b/entity/Offer_entity/entityfields/newtask/onActionProcess.js
index b77c8343aa0def1afccab6e7c4a4dc5558da7e9b..f0165851eda69a6c3a0187d29f05c133b4118ed3 100644
--- a/entity/Offer_entity/entityfields/newtask/onActionProcess.js
+++ b/entity/Offer_entity/entityfields/newtask/onActionProcess.js
@@ -7,7 +7,7 @@ var links = [];
 
 if (contactId)
 {
-    links.push([ContactUtils.getContextByRelationId(contactId), contactId]);
+    links.push([ContactUtils.getContextByContactId(contactId), contactId]);
 }
 
 if (vars.get("$field.SALESPROJECT_ID"))
diff --git a/entity/Offer_entity/entityfields/salesproject_id/mandatoryProcess.js b/entity/Offer_entity/entityfields/salesproject_id/mandatoryProcess.js
index 05b1f9bd5c0c54e2c707e0ac6f2fce2ea12850e0..3bd7da35b29fe62a814c8f4562736441d1b99708 100644
--- a/entity/Offer_entity/entityfields/salesproject_id/mandatoryProcess.js
+++ b/entity/Offer_entity/entityfields/salesproject_id/mandatoryProcess.js
@@ -2,7 +2,7 @@ import("system.vars");
 import("system.result");
 import("Contact_lib");
 
-var type = ContactUtils.getRelationType(vars.get("$field.CONTACT_ID"), vars.get("$field.CONTACT_PERSON_ID"), vars.get("$field.CONTACT_ORG_ID"));
+var type = ContactUtils.getContactType(vars.get("$field.CONTACT_ID"), vars.get("$field.CONTACT_PERSON_ID"), vars.get("$field.CONTACT_ORG_ID"));
 
 result.string(type != 2);
 
diff --git a/entity/Offer_entity/entityfields/tasks/children/presetlinks_param/valueProcess.js b/entity/Offer_entity/entityfields/tasks/children/presetlinks_param/valueProcess.js
index db35a547ac2cbf60774b6ddb9be4781b81196a68..e4c6c134df6be187331e47d8c2c4d5a9871b7c2b 100644
--- a/entity/Offer_entity/entityfields/tasks/children/presetlinks_param/valueProcess.js
+++ b/entity/Offer_entity/entityfields/tasks/children/presetlinks_param/valueProcess.js
@@ -7,7 +7,7 @@ var links = [];
 
 if (contactId)
 {
-    links.push([ContactUtils.getContextByRelationId(contactId), contactId]);
+    links.push([ContactUtils.getContextByContactId(contactId), contactId]);
 }
 
 if (vars.get("$field.SALESPROJECT_ID"))
diff --git a/entity/Order_entity/entityfields/activities/children/presetlinks_param/valueProcess.js b/entity/Order_entity/entityfields/activities/children/presetlinks_param/valueProcess.js
index db35a547ac2cbf60774b6ddb9be4781b81196a68..e4c6c134df6be187331e47d8c2c4d5a9871b7c2b 100644
--- a/entity/Order_entity/entityfields/activities/children/presetlinks_param/valueProcess.js
+++ b/entity/Order_entity/entityfields/activities/children/presetlinks_param/valueProcess.js
@@ -7,7 +7,7 @@ var links = [];
 
 if (contactId)
 {
-    links.push([ContactUtils.getContextByRelationId(contactId), contactId]);
+    links.push([ContactUtils.getContextByContactId(contactId), contactId]);
 }
 
 if (vars.get("$field.SALESPROJECT_ID"))
diff --git a/entity/Order_entity/entityfields/contact_id/linkedContextProcess.js b/entity/Order_entity/entityfields/contact_id/linkedContextProcess.js
index e678b842c5b6cf510473693a355fa7833dcf28e8..2e504d63e3b5a3f71b54b072798b3ad09c50984b 100644
--- a/entity/Order_entity/entityfields/contact_id/linkedContextProcess.js
+++ b/entity/Order_entity/entityfields/contact_id/linkedContextProcess.js
@@ -2,4 +2,4 @@ import("system.vars");
 import("system.result");
 import("Contact_lib");
 
-result.string(ContactUtils.getContextByRelationId(vars.getString("$field.CONTACT_ID")));
\ No newline at end of file
+result.string(ContactUtils.getContextByContactId(vars.getString("$field.CONTACT_ID")));
\ No newline at end of file
diff --git a/entity/Order_entity/entityfields/newactivity/onActionProcess.js b/entity/Order_entity/entityfields/newactivity/onActionProcess.js
index 52c2254f6fb64e4784e400dfe61d00e2f2013197..1a27d3d454d20447d05ec6064c1852a7d9e49d01 100644
--- a/entity/Order_entity/entityfields/newactivity/onActionProcess.js
+++ b/entity/Order_entity/entityfields/newactivity/onActionProcess.js
@@ -7,7 +7,7 @@ var links = [];
 
 if (contactId)
 {
-    links.push([ContactUtils.getContextByRelationId(contactId), contactId]);
+    links.push([ContactUtils.getContextByContactId(contactId), contactId]);
 }
 
 if (vars.get("$field.SALESPROJECT_ID"))
diff --git a/entity/Order_entity/entityfields/newtask/onActionProcess.js b/entity/Order_entity/entityfields/newtask/onActionProcess.js
index a2fb8e983a3a08d7bda6b2a66f520f4fdc2ba719..3d0aeaf0beab976054701f3a58a709df8e67de92 100644
--- a/entity/Order_entity/entityfields/newtask/onActionProcess.js
+++ b/entity/Order_entity/entityfields/newtask/onActionProcess.js
@@ -7,7 +7,7 @@ var links = [];
 
 if (contactId)
 {
-    links.push([ContactUtils.getContextByRelationId(contactId), contactId]);
+    links.push([ContactUtils.getContextByContactId(contactId), contactId]);
 }
 
 if (vars.get("$field.SALESPROJECT_ID"))
diff --git a/entity/Order_entity/entityfields/tasks/children/presetlinks_param/valueProcess.js b/entity/Order_entity/entityfields/tasks/children/presetlinks_param/valueProcess.js
index db35a547ac2cbf60774b6ddb9be4781b81196a68..e4c6c134df6be187331e47d8c2c4d5a9871b7c2b 100644
--- a/entity/Order_entity/entityfields/tasks/children/presetlinks_param/valueProcess.js
+++ b/entity/Order_entity/entityfields/tasks/children/presetlinks_param/valueProcess.js
@@ -7,7 +7,7 @@ var links = [];
 
 if (contactId)
 {
-    links.push([ContactUtils.getContextByRelationId(contactId), contactId]);
+    links.push([ContactUtils.getContextByContactId(contactId), contactId]);
 }
 
 if (vars.get("$field.SALESPROJECT_ID"))
diff --git a/entity/Organisation_entity/Organisation_entity.aod b/entity/Organisation_entity/Organisation_entity.aod
index 1c9253f9ce066a6edf0d3b8fa50a36f517d8f4c7..ea7df11cc5e14ae0284e09a69f3f0f3d96648c43 100644
--- a/entity/Organisation_entity/Organisation_entity.aod
+++ b/entity/Organisation_entity/Organisation_entity.aod
@@ -187,6 +187,7 @@
       <consumer>Addresses</consumer>
       <searchable v="false" />
       <state>AUTO</state>
+      <valueProcess>%aditoprj%/entity/Organisation_entity/entityfields/address_id/valueProcess.js</valueProcess>
       <displayValueProcess>%aditoprj%/entity/Organisation_entity/entityfields/address_id/displayValueProcess.js</displayValueProcess>
     </entityField>
     <entityConsumer>
@@ -639,6 +640,7 @@
       <alias>Data_alias</alias>
       <fromClauseProcess>%aditoprj%/entity/Organisation_entity/recordcontainers/db/fromClauseProcess.js</fromClauseProcess>
       <conditionProcess>%aditoprj%/entity/Organisation_entity/recordcontainers/db/conditionProcess.js</conditionProcess>
+      <onDBInsert>%aditoprj%/entity/Organisation_entity/recordcontainers/db/onDBInsert.js</onDBInsert>
       <onDBUpdate>%aditoprj%/entity/Organisation_entity/recordcontainers/db/onDBUpdate.js</onDBUpdate>
       <linkInformation>
         <linkInformation>
diff --git a/entity/Organisation_entity/recordcontainers/db/onDBInsert.js b/entity/Organisation_entity/recordcontainers/db/onDBInsert.js
new file mode 100644
index 0000000000000000000000000000000000000000..ba0e67422c062558e49b062c65e43e35fa5e2b95
--- /dev/null
+++ b/entity/Organisation_entity/recordcontainers/db/onDBInsert.js
@@ -0,0 +1,3 @@
+import("system.logging");
+import("system.vars");
+
diff --git a/process/PostalAddress_lib/process.js b/process/PostalAddress_lib/process.js
index 40445e11ecbd90447ef35c2df80f330ee39473fc..7c96f2e6238755fb2a5f0ce3aa4fdd825abdfdf0 100644
--- a/process/PostalAddress_lib/process.js
+++ b/process/PostalAddress_lib/process.js
@@ -63,8 +63,8 @@ AddressUtils.getFormattedOnlineAddressById = function(pAddressId)
  * 
  * @return {String}
  */
-AddressUtils.getAddress = function(pRelationId) {
-    var address = db.array(db.ROW, SqlCondition.begin().andPrepare("CONTACT.CONTACTID", pRelationId).buildSql('select CONTACTID, ADDRESS, BUILDINGNO, ZIP, CITY, "NAME", FIRSTNAME, LASTNAME, TITLE from' + ContactUtils.getFullRelationString(), "1=0"));
+AddressUtils.getAddress = function(pContactId) {
+    var address = db.array(db.ROW, SqlCondition.begin().andPrepare("CONTACT.CONTACTID", pContactId).buildSql('select CONTACTID, ADDRESS, BUILDINGNO, ZIP, CITY, "NAME", FIRSTNAME, LASTNAME, TITLE from' + ContactUtils.getFullContactString(), "1=0"));
     
     // TODO: currently there are some relations without standard address. Use Hardcoded one.
     if (!address[1]) {
@@ -75,7 +75,7 @@ AddressUtils.getAddress = function(pRelationId) {
         address[4] = dummyAddress[3];
         
     }
-    var type = ContactUtils.getRelationTypeByRelation(pRelationId);
+    var type = ContactUtils.getContactTypeByContact(pContactId);
     
     return AddressUtils.formatAddress(type, address[1], address[2], address[3], address[4], address[5], address[6], address[7], address[8]);
 }
@@ -103,7 +103,7 @@ AddressUtils.getAddressById = function(pAddressId) {
         address[4] = dummyAddress[4];
         
     }
-    var type = ContactUtils.getRelationTypeByRelation(address[0]);   
+    var type = ContactUtils.getContactTypeByContact(address[0]);   
 
     var names = db.array(db.ROW, SqlCondition.begin()
                                              .andPrepare("CONTACT.CONTACTID", address[0])
diff --git a/process/Contact_lib/process.js b/process/Contact_lib/process.js
index b3e659f848a3d5c46b8376121477ea329ebbffac..c3b389da09df881d03b868f494842688ead8aeb1 100644
--- a/process/Contact_lib/process.js
+++ b/process/Contact_lib/process.js
@@ -50,7 +50,7 @@ function ContactUtils() {}
  * This saves an extra select from CONTACT. <br>
  *  <br>
  *  <br>
- * @param {String} pRelationId
+ * @param {String} pContactId
  * @param {String} pPersId selected from the CONTACT table
  * @param {String} pOrgId selected from the CONTACT table
  *  <br>
@@ -59,34 +59,34 @@ function ContactUtils() {}
  *                      2 if privat person <br>
  *                      3 if person of an organisation <br>
  */
-ContactUtils.getRelationType = function(pRelationId, pPersId, pOrgId)
+ContactUtils.getContactType = function(pContactId, pPersId, pOrgId)
 {
     if (vars.get("$sys.recordstate") == neon.OPERATINGSTATE_NEW || vars.get("$sys.recordstate") == neon.OPERATINGSTATE_EDIT)
     {
-        return ContactUtils.getRelationTypeByRelation(pRelationId);
+        return ContactUtils.getContactTypeByContact(pContactId);
     }
     else
     {
-        return ContactUtils.getRelationTypeByPersOrg(pPersId, pOrgId);
+        return ContactUtils.getContactTypeByPersOrg(pPersId, pOrgId);
     }
 }
 
 /**
  * get the type of contact for a relationId <br>
  * If you already have persId and orgId from the CONTACT table, use getRelationTypeByPersOrg() <br>
  * @param {String} pRelationId
  * <br>
  * @return {Integer} 0 if relationId not found <br>
  *                  1 if organisation <br>
  *                  2 if privat person <br>
  *                  3 if person of an organisation <br>
  */
-ContactUtils.getRelationTypeByRelation = function(pRelationId)
+ContactUtils.getContactTypeByContact = function(pContactId)
 {
-    var relationData = ContactUtils.getPersOrgIds(pRelationId);
+    var relationData = ContactUtils.getPersOrgIds(pContactId);
     if (relationData[0]) 
     {
-        return this.getRelationTypeByPersOrg(relationData[1], relationData[2]);
+        return this.getContactTypeByPersOrg(relationData[1], relationData[2]);
     }
     else
     {
@@ -102,7 +102,7 @@ ContactUtils.getRelationTypeByRelation = function(pRelationId)
  * !!It does not check if the person / org ids really exist!! <br>
  * !!And it does not check if really any contact with this person / org ids exist!! <br>
  *  <br>
  * This function is more performant than getRelationTypeByRelation, <br>
  * because it doesn't load something from the db. <br>
  *  <br>
  * It is meant to be used by entitys, where you can load person and org with the DataRecord. <br>
@@ -116,7 +116,7 @@ ContactUtils.getRelationTypeByRelation = function(pRelationId)
  *                      2 if privat person <br>
  *                      3 if person of an organisation <br>
  */
-ContactUtils.getRelationTypeByPersOrg = function(pPersId, pOrgId)
+ContactUtils.getContactTypeByPersOrg = function(pPersId, pOrgId)
 {
     if (!pPersId)
     {
@@ -147,7 +147,7 @@ ContactUtils.getRelationTypeByPersOrg = function(pPersId, pOrgId)
  * !!It does not check if the person / org ids really exist!! <br>
  * !!And it does not check if really any contact with this person / org ids exist!! <br>
  *  <br>
  * This function is more performant than getContextByRelationId, <br>
  * because it doesn't load something from the db. <br>
  *  <br>
  * It is meant to be used by entitys, where you can load person and org with the DataRecord. <br>
@@ -161,7 +161,7 @@ ContactUtils.getRelationTypeByPersOrg = function(pPersId, pOrgId)
  */
 ContactUtils.getContextByPersOrg = function(pPersId, pOrgId)
 {
-    switch (ContactUtils.getRelationTypeByPersOrg(pPersId, pOrgId))
+    switch (ContactUtils.getContactTypeByPersOrg(pPersId, pOrgId))
     {
         case 1: // Org
             return ContextUtils.getContextName("Organisation");
@@ -177,27 +177,27 @@ ContactUtils.getContextByPersOrg = function(pPersId, pOrgId)
  * return the corresponding context of the contact <br>
  * If you already have persId and orgId from the CONTACT table, use getContextByPersOrg() <br>
  * 
- * @param {String} pRelationId
+ * @param {String} pContactId
  * @return {String} contextname or "" if contact not found
  */
-ContactUtils.getContextByRelationId = function(pRelationId)
+ContactUtils.getContextByContactId = function(pContactId)
 {
-    var relationData = ContactUtils.getPersOrgIds(pRelationId);
+    var relationData = ContactUtils.getPersOrgIds(pContactId);
     return ContactUtils.getContextByPersOrg(relationData[1], relationData[2])
 }
 
 /**
  * get the person- and org-id from a contact as array
  * 
- * @param {String} pRelationId
+ * @param {String} pContactId
  * @return {String[]} result as [persid, orgid] if one of them is null in the db, "" will be returned as the id.
  */
-ContactUtils.getPersOrgIds = function(pRelationId)
+ContactUtils.getPersOrgIds = function(pContactId)
 {
-    if (pRelationId) {
+    if (pContactId) {
         return db.array(db.ROW, 
             SqlCondition.begin()
-                        .andPrepare("CONTACT.CONTACTID", pRelationId)
+                        .andPrepare("CONTACT.CONTACTID", pContactId)
                         .buildSql("select CONTACTID, PERSON_ID, ORGANISATION_ID from CONTACT", "1=0"));
     }
     
@@ -264,14 +264,13 @@ ContactUtils.getTitleByPersonId = function(pPersonId)
  *
  * @return {String}
  */
-ContactUtils.getFullRelationString = function()
+ContactUtils.getFullContactString = function()
 {
     return " CONTACT join ORGANISATION on ORGANISATION.ORGANISATIONID = CONTACT.ORGANISATION_ID"
     + " left join PERSON on PERSON.PERSONID = CONTACT.PERSON_ID"
     + " left join ADDRESS on ADDRESS.ADDRESSID = CONTACT.ADDRESS_ID";
 }
 
-
 /**
  * object for handling of a single contact
  * provides static- and instance-functions
@@ -59,34 +59,34 @@ function ContactUtils() {}
 /**
  * get the type of contact for a relationId <br>
- * If you already have persId and orgId from the CONTACT table, use getRelationTypeByPersOrg() <br>
- * @param {String} pRelationId
+ * If you already have persId and orgId from the CONTACT table, use getContactTypeByPersOrg() <br>
+ * @param {String} pContactId
  * <br>
  * @return {Integer} 0 if relationId not found <br>
@@ -102,7 +102,7 @@ ContactUtils.getRelationTypeByRelation = function(pRelationId)
  * !!And it does not check if really any contact with this person / org ids exist!! <br>
  *  <br>
- * This function is more performant than getRelationTypeByRelation, <br>
+ * This function is more performant than getContactTypeByContact, <br>
  * because it doesn't load something from the db. <br>
  *  <br>
@@ -147,7 +147,7 @@ ContactUtils.getRelationTypeByPersOrg = function(pPersId, pOrgId)
  * !!And it does not check if really any contact with this person / org ids exist!! <br>
  *  <br>
- * This function is more performant than getContextByRelationId, <br>
+ * This function is more performant than getContextByContactId, <br>
  * because it doesn't load something from the db. <br>
  *  <br>